# GeneralAviationAircraftFamilyBenchmark (GAAFPy)
A Python implementation of the GAA family benchmark problem developed by T.W. Simpson, W. Chen. J.K. Allen, F. Mistree, B.S. D'Souza, R. Shah, P.M. Reed, and D. Hadka. 

This repository is fundamentally a Python translation of the RealWorldBenchmarks implementation in the MOEA framework by Zatarain Salazar, J., Hadka, D., Reed, P., Seada, H., & Deb, K (see reference 5).

## Requirements
The framework is tested to work using the following Python version and packages:
1. Python >= 3.13.12
2. Numpy >= 2.4.3

## Installation
The recommended method is through PyPi by running the command: 

```
pip install gaafpy
```

## Community Guidelines

This software is currently being maintained by me @TSVermeulen. If you find any bugs, want to contribute or have any questions, you can either open a ticket here on GitHub or send me an email at T.S.Vermeulen@tudelft.nl 

## License
The Benchmark problem is copyright by the respective authors. Please cite them as appropriate if using the benchmark problem. 

## References
1. T. W. Simpson, W. Chen, J. K. Allen, and F. Mistree (1996). "Conceptual design of a family
   of products through the use of the robust concept exploration method." In 6th AIAA/USAF/NASA/
   ISSMO Symposium on Multidiciplinary Analysis and Optimization, vol. 2, pp. 1535-1545.
   ([Link](http://www.researchgate.net/publication/236735937_Conceptual_Design_of_a_Family_of_Products_Through_the_Use_of_the_Robust_Concept_Exploration_Method))

2. T. W. Simpson, B. S. D'Souza (2004). "Assessing variable levels of platform commonality within
   a product family using a multiobjective genetic algorithm." Concurrent Engineering:
   Research and Applications, vol. 12, no. 2, pp. 119-130.
   ([Link](http://cer.sagepub.com/content/12/2/119.abstract))

3. R. Shah, P. M. Reed, and T. W. Simpson (2011). "Many-objective evolutionary optimization and
   visual analytics for product family design." Multiobjective Evolutionary Optimisation for
   Product Design and Manufacturing, Springer, London, pp. 137-159.
   ([Link](http://link.springer.com/chapter/10.1007/978-0-85729-652-8_4))

4. D. Hadka, P. M. Reed, and T. W. Simpson (2012). "Diagnostic Assessment of the Borg MOEA on 
   Many-Objective Product Family Design Problems."  WCCI 2012 World Congress on Computational
   Intelligence, Congress on Evolutionary Computation, Brisbane, Australia, pp. 986-995.
   ([Link](http://ieeexplore.ieee.org/xpl/articleDetails.jsp?arnumber=6256466))

5. Zatarain Salazar, J., Hadka, D., Reed, P., Seada, H., & Deb, K. (2024). Diagnostic benchmarking
   of many-objective evolutionary algorithms for real-world problems. Engineering Optimization, 1–22. ([Link](https://doi.org/10.1080/0305215X.2024.2381818))
